@@ -32,6 +32,10 @@ static const char description[] = I18N_NOOP("KMouseTool");
 
 int main(int argc, char *argv[])
 {
+    // enable high dpi support
+    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
+
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("kmousetool");
 
